==> proxino-0.0.5.tgz: package/proxino.js <==
var jsp = require("uglify-js").parser;
var pro = require("uglify-js").uglify;
var fs = require("fs");

function wrap_exception(block){
  return [[ "try", // XXX: "block" is safer
          block,
          [ "proxino_exception", 
            [ ["stat", 
                ["call", ["name", "Proxino.x"],
                  [ ["name", "proxino_exception"],
                    ["name", "arguments"]
                  ] 
                ]
              ] 
            ]
          ]]];
};

function proxino(code) {
        var ast = jsp.parse(code, false, true); // true for the third arg specifies that we want
                                                // to have start/end tokens embedded in the statements
        var w = pro.ast_walker();
        // we're gonna need this to push elements that we're currently looking at, to avoid
        // endless recursion.
        var analyzing = [];
        function ins_exc() {
                var ret;
                if (this[0].start && analyzing.indexOf(this) < 0) {
                        // without the `analyzing' hack, w.walk(this) would re-enter here leading
                        // to infinite recursion
                        analyzing.push(this);
                        ret = w.walk(this);
                        ret[3] = wrap_exception(ret[3]);
                        analyzing.pop(this);
                }
                return ret;
        };
        var new_ast = w.with_walkers({
                "defun" : ins_exc,
                "function" : ins_exc, 
        }, function(){
                return w.walk(ast);
        });
        return pro.gen_code(new_ast, { beautify: false });
}

module.exports = proxino

==> proxino-0.0.6.tgz: package/proxino.js <==
var jsp = require("uglify-js").parser;
var pro = require("uglify-js").uglify;
var fs = require("fs");

function wrap_exception(block, func){
  return [[ "try", // XXX: "block" is safer
          block,
          [ "proxino_exception", 
            [ ["stat", 
                ["call", ["name", func],
                  [ ["name", "proxino_exception"],
                    ["name", "arguments"]
                  ] 
                ]
              ] 
            ]
          ]]];
};

function proxino(code, func, options) {
        var ast = jsp.parse(code, false, true); // true for the third arg specifies that we want
                                                // to have start/end tokens embedded in the statements
        var w = pro.ast_walker();
        // we're gonna need this to push elements that we're currently looking at, to avoid
        // endless recursion.
        var analyzing = [];
        function ins_exc() {
                var ret;
                if (this[0].start && analyzing.indexOf(this) < 0) {
                        // without the `analyzing' hack, w.walk(this) would re-enter here leading
                        // to infinite recursion
                        analyzing.push(this);
                        ret = w.walk(this);
                        ret[3] = wrap_exception(ret[3],func);
                        analyzing.pop(this);
                }
                return ret;
        };
        var new_ast = w.with_walkers({
                "defun" : ins_exc,
                "function" : ins_exc, 
        }, function(){
                return w.walk(ast);
        });
        return pro.gen_code(new_ast, options);
};

module.exports = proxino
